@@ -1,8 +1,7 @@
-from dataclasses import dataclass
+from dataclasses import dataclass, asdict
 import os
 from enum import IntEnum
 from typing import Any, List, Dict
-from attr import asdict
 
 import streamlit.components.v1 as components
 
@@ -78,8 +77,9 @@ if not _RELEASE:
     st.subheader("Multi String Component")
     num_clicks = multi_row_inputs("wow", [
             InputInfo(InputType.LONG_TEXT, "Event", 2, 0),
-            InputInfo(InputType.SHORT_TEXT, "Location", 1, 0)
-        ], line_num=1, default_list=[["Free time", "Del pino resort"]], key="foo")
+            InputInfo(InputType.SHORT_TEXT, "Location", 1, 0),
+            InputInfo(InputType.DATETIME, "datetime", 1, 1)
+        ], line_num=2, default_list=[["Free time", "Del pino resort"]], key="foo")
     
     for i in num_clicks:
         st.write(i)
